@@ -97,9 +97,9 @@ def reader(server):
 				try:
 					subprocess.call([cmd, 'Email number, ' + str(msg_num)])
 					time.sleep(0.5)
-					subprocess.call([cmd, 'Subject - ', Subject])
+					subprocess.call([cmd, 'Subject - ' + Subject])
 					time.sleep(0.5)
-					subprocess.call([cmd, 'Message - ', Message])
+					subprocess.call([cmd, 'Message - ' + Message])
 					time.sleep(1)
 				except:
 					print "Error: \"Make sure your operating system is compliant with gmreader (i.e. mac osx, linux, windows). If linux or windows(with cygwin), you must have espeak installed on your machine.\""
